gleeps
Types
TBD
pub type Action
pub type Armor {
WoodenArmor
MetalArmor
}
Constructors
-
WoodenArmor -
MetalArmor
Used to produce weapons and armor
pub type Armory {
ArmoryStructure
}
Constructors
-
ArmoryStructure
Like a wall, but walkable for friendlies.
pub type Gate {
GateStructure
}
Constructors
-
GateStructure
Large housing capacity and unit generation over time.
pub type House {
HouseStructure
}
Constructors
-
HouseStructure
pub type Position {
Position(x: Int, y: Int)
}
Constructors
-
Position(x: Int, y: Int)
pub type Runtime(state) {
Runtime(
init: fn() -> state,
encode: fn(state) -> json.Json,
decode: decode.Decoder(state),
loop: fn(state, World) -> #(state, List(Action)),
)
}
Constructors
-
Runtime( init: fn() -> state, encode: fn(state) -> json.Json, decode: decode.Decoder(state), loop: fn(state, World) -> #(state, List(Action)), )
pub type Structure {
Watchtower(
position: Position,
health: Int,
structure: Watchtower,
)
Cart(position: Position, health: Int, structure: Cart)
Shack(position: Position, health: Int, structure: Shack)
Storage(position: Position, health: Int, structure: Storage)
Tower(position: Position, health: Int, structure: Tower)
Wall(position: Position, health: Int, structure: Wall)
Gate(position: Position, health: Int, structure: Gate)
House(position: Position, health: Int, structure: House)
Armory(position: Position, health: Int, structure: Armory)
Toolsmith(
position: Position,
health: Int,
structure: Toolsmith,
)
}
Constructors
-
Watchtower( position: Position, health: Int, structure: Watchtower, )Increased vision & ranged attack range
-
Movable storage
-
Small housing capacity and unit generation over time.
May be upgraded to a house or armory.
-
Storage for any one resource
-
Upgraded watchtower Increased vision, ranged attack range and damage resistance.
Slots in between walls & gates
-
Blocks any and all units from moving through a tile. Self explanatory.
-
Like a wall, but walkable for friendlies.
-
Large housing capacity and unit generation over time.
-
Used to produce weapons and armor
-
Used to produce tools to increase work speed and yield
pub type Terrain {
Plains
Swamp
Blocked
}
Constructors
-
PlainsNormal tile
-
SwampHarder to move through
-
BlockedImpossible to move through
Denotes a specific game tick
pub type Tick {
Tick(Int)
}
Constructors
-
Tick(Int)
Used to produce tools to increase work speed and yield
pub type Toolsmith {
ToolsmithStructure
}
Constructors
-
ToolsmithStructure
Upgraded watchtower Increased vision, ranged attack range and damage resistance.
Slots in between walls & gates
pub type Tower {
TowerStructure
}
Constructors
-
TowerStructure
Blocks any and all units from moving through a tile. Self explanatory.
pub type Wall {
WallStructure
}
Constructors
-
WallStructure
Increased vision & ranged attack range
pub type Watchtower {
WatchtowerStructure
}
Constructors
-
WatchtowerStructure
pub type Weapon {
Stick
Bow
Spear
Sword
}
Constructors
-
Stick -
Bow -
Spear -
Sword
TBD
pub type WorldState {
WorldState
}
Constructors
-
WorldStateTBD